import time

from datetime import datetime, timedelta
from calendar import monthrange
from netforce.model import Model, fields, get_model
from netforce.access import get_active_company

from . import utils

class VisitDialy(Model):
    _name="clinic.visit.dialy"
    _string="Visit Dialy"
    _transient=True
    
    _fields={
        "date_from": fields.Date("From", required=True),
        "date_to": fields.Date("To", required=True),
    }

    _defaults={
        'date_from': lambda *a: time.strftime("%Y-%m-%d"),        
        'date_to': lambda *a: (datetime.now()+timedelta(days=7)).strftime("%Y-%m-%d"),        
    }
    
    def get_report_data(self,ids,context={}):
        company_id=get_active_company()
        company=get_model("company").browse(company_id)

        date_from=datetime.now().strftime("%Y-%m-%d")
        date_to=(datetime.now()+timedelta(days=7)).strftime("%Y-%m-%d")

        if ids:
            obj=self.browse(ids)[0]
            date_from=obj.date_from
            date_to=obj.date_to

        time_start='%s 00:00:00'%(date_from)
        time_stop='%s 23:59:59'%(date_to)

        month=int(date_from[5:7])
        year=date_from[0:4]
        day=date_from[8:10]
        month_str=utils.MONTHS['th_TH'][month]  
        dom=[]
        dom.append(['time_start','>=','%s'%time_start])
        dom.append(['time_stop','<=','%s'%time_stop])
        lines=[]

        empty_line={
            'number': '',
            'visit_id': None,
            'cycle_name': '',
            'cycle_color': '',
            'patient_name': '',
            'doctor_name': '',
            'hd_case_number': '',
            'hd_case_id': None,
            'success_color': '',
        }
        for obj in get_model("clinic.visit").search_browse(dom):
            hd_case_id=None
            hd_case_number=''
            if obj.hd_cases:
                hd_case=obj.hd_cases[0]
                hd_case_id=hd_case.id,
                hd_case_number=hd_case.number,
            number=obj.number
            if number=='/':
                number='รอการรรักษา'
            cycle=obj.cycle_id
            line={
                'number': number,
                'visit_id': obj.id,
                'cycle_name': cycle.name,
                'cycle_color': cycle.color,
                'patient_name': obj.patient_id.name,
                'doctor_name': obj.doctor_id.name,
                'hd_case_number': hd_case_number,
                'hd_case_id': hd_case_id,
                'success_color':  obj.state=='confirmed' and '#99ff99' or ''
            }
            lines.append(line)
        
        year=int(year)+543
        date_str='%s %s %s'%(day,month_str,year)
        has_duration=False
        if date_from != date_to:
            has_duration=True

        data={
            'lines': lines,
            'date': date_str,
            'company_name': company.name,
            'company_parent_name': company.parent_id.name,
            'has_duration': has_duration,
            'date_from': date_from,
            'date_to': date_to,
        }

        return data

VisitDialy.register()
